@@ -54,6 +54,9 @@
 
 #ifdef WIN32
 #include "winpaths.h"
+#include <shellapi.h>
+#define WIN32_HELP_DIR "help"
+#define WIN32_HELP_FILE "index.xhtml"
 #endif
 
 /* The callbacks */
@@ -67,18 +70,18 @@ save_callback (GtkWidget *widget,
 
 
 gboolean
-delete_window_cb (GtkWidget *w,
-                  GdkEvent *ev,
+delete_window_cb (GtkWidget *widget,
+                  GdkEvent *event,
                   gpointer data)
 {
-  gnomemeeting_window_hide (GTK_WIDGET (w));
+  gnomemeeting_window_hide (GTK_WIDGET (widget));
 
   return TRUE;
 }
 
 
 void
-show_window_cb (GtkWidget *w,
+show_window_cb (GtkWidget *widget,
 		gpointer data)
 {
   if (!gnomemeeting_window_is_visible (GTK_WIDGET (data)))
@@ -89,7 +92,7 @@ show_window_cb (GtkWidget *w,
 
 
 void
-hide_window_cb (GtkWidget *w,
+hide_window_cb (GtkWidget *widget,
 		gpointer data)
 {
   if (gnomemeeting_window_is_visible (GTK_WIDGET (data)))
@@ -115,6 +118,11 @@ void
 disconnect_cb (GtkWidget *widget,
 	       gpointer data)
 {	
+  GtkWidget *main_window = NULL;
+
+  main_window = GnomeMeeting::Process ()->GetMainWindow ();
+  gm_main_window_push_message (main_window, _("Disconnecting..."));
+
   gdk_threads_leave ();
   GnomeMeeting::Process ()->Disconnect ();
   gdk_threads_enter ();
@@ -177,7 +185,7 @@ about_callback (GtkWidget *widget,
 			  (const char **) authors,
                           (const char **) documenters,
                           strcmp (translator_credits, 
-				  "translator_credits") != 0 ? 
+				  "translator-credits") != 0 ? 
                           translator_credits : "No translators, English by\n"
                           "Damien Sandras <dsandras@seconix.com>",
 			  pixbuf);
@@ -197,6 +205,43 @@ help_cb (GtkWidget *widget,
 #ifndef DISABLE_GNOME
   GError *err = NULL;
   gnome_help_display (PACKAGE_NAME ".xml", NULL, &err);
+#else
+#ifdef WIN32
+  gchar *locale, *loc_ , *index_path;
+  int hinst = 0;
+
+  locale = g_win32_getlocale ();
+  if (strlen (locale) > 0) {
+
+    /* try returned locale first, it may be fully qualified e.g. zh_CN */
+    index_path = g_build_filename (WIN32_HELP_DIR, locale,
+				   WIN32_HELP_FILE, NULL);
+    hinst = (int) ShellExecute (NULL, "open", index_path, NULL,
+			  	DATA_DIR, SW_SHOWNORMAL);
+    g_free (index_path);
+  }
+
+  if (hinst <= 32 && (loc_ = g_strrstr (locale, "_"))) {
+    /* on error, try short locale */
+    *loc_ = 0;
+    index_path = g_build_filename (WIN32_HELP_DIR, locale,
+				   WIN32_HELP_FILE, NULL);
+    hinst = (int) ShellExecute (NULL, "open", index_path, NULL,
+				DATA_DIR, SW_SHOWNORMAL);
+    g_free (index_path);
+  }
+
+  g_free (locale);
+
+  if (hinst <= 32) {
+
+    /* on error or missing locale, try default locale */
+    index_path = g_build_filename (WIN32_HELP_DIR, "C", WIN32_HELP_FILE, NULL);
+    (void)ShellExecute (NULL, "open", index_path, NULL,
+			DATA_DIR, SW_SHOWNORMAL);
+    g_free (index_path);
+  }
+#endif
 #endif
 }
 
@@ -332,7 +377,7 @@ entry_completion_url_match_cb (GtkEntryCompletion *completion,
 
 
 void 
-connect_button_clicked_cb (GtkToggleButton *w, 
+connect_button_clicked_cb (GtkToggleButton *widget, 
 			   gpointer data)
 {
   GMManager *ep = NULL;
@@ -344,15 +389,15 @@ connect_button_clicked_cb (GtkToggleButton *w,
   ep = GnomeMeeting::Process ()->GetManager ();
   
   /* Button is in disconnected state */
-  if (!gm_connect_button_get_connected (GM_CONNECT_BUTTON (w))
+  if (!gm_connect_button_get_connected (GM_CONNECT_BUTTON (widget))
       && ep->GetCallingState () == GMManager::Standby) {
       
     if (!GMURL (url).IsEmpty ())
       GnomeMeeting::Process ()->Connect (url);
     else
-      gm_connect_button_set_connected (GM_CONNECT_BUTTON (w), FALSE);
+      gm_connect_button_set_connected (GM_CONNECT_BUTTON (widget), FALSE);
   }
-  else if (gm_connect_button_get_connected (GM_CONNECT_BUTTON (w))
+  else if (gm_connect_button_get_connected (GM_CONNECT_BUTTON (widget))
 	   && ep->GetCallingState () != GMManager::Standby) {
 
     gdk_threads_leave();
@@ -360,5 +405,5 @@ connect_button_clicked_cb (GtkToggleButton *w,
     gdk_threads_enter();
   }
   else 
-    gm_connect_button_set_connected (GM_CONNECT_BUTTON (w), FALSE);
+    gm_connect_button_set_connected (GM_CONNECT_BUTTON (widget), FALSE);
 }
